# wsnet
A lightweight protocol implementation to perform TCP and authentication proxying over websockets.  
It's actually Layer3 agnostic, but websockets was easy to use.

# If you are here for the OctoPwn
## Install
Either use PIP `pip install wsnet` or clone + install via GitHub.
## Starting server
After installing you should have a new binary called `wssserver`.  
It has a help menu, but really there is not much to change there.

# If you are here to see what this is
Sorry, for the time being you'll need to read the code.
